<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:java="http://xml.apache.org/xslt/java"
	xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
	xmlns:gslib="http://www.greenstone.org/skinning"
	extension-element-prefixes="java util"
	exclude-result-prefixes="java util">

	<xsl:variable name="groupPath"><xsl:value-of select="/page/pageRequest/paramList/param[@name='group']/@value"/></xsl:variable>
	
	<!-- use the 'main' layout -->
	<!--<xsl:include href="layouts/main.xsl"/>-->

	<!-- set page title -->
	<xsl:template name="pageTitle"><xsl:choose><xsl:when test="$groupPath != ''"><gslib:groupName path="{$groupPath}"/></xsl:when><xsl:otherwise><gslib:siteName/></xsl:otherwise></xsl:choose></xsl:template>

	<!-- set page breadcrumbs -->
	<xsl:template name="breadcrumbs">
		<xsl:if test="$groupPath != ''">
			<gslib:siteLink/>
			<xsl:for-each select="/page/pageResponse/pathList/group">
				<xsl:sort data-type="number" select="@position"/>
				<gslib:rightArrow/>
				<xsl:if test="position() != last()">
				  <!-- don't want the current group in the breadcrumbs -->
				  <a>
				    <xsl:attribute name="href"><gslib:groupHref path="{@path}"/></xsl:attribute>				
				    <xsl:attribute name="title"><gslib:groupName path="{@path}"/></xsl:attribute>
				    <gslib:groupName path="{@path}"/>
				  </a>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>
	
	<!-- the page content -->
	<xsl:template match="/page/pageResponse">
	  <div class="main-wrap">
	    
	    <div id="wsite-content" class="wsite-elements wsite-not-footer">
	      <div class="wsite-section-wrap">
		<div class="wsite-section wsite-body-section wsite-background-14"  >
		  <div class="wsite-section-content">
		    <div class="container">
		      <div class="wsite-section-elements">
			<div class="wsite-spacer" style="height:50px;"></div>

			<div><div class="wsite-multicol"><div class="wsite-multicol-table-wrap" style="margin:0 -15px;">
			  <table class="wsite-multicol-table">
			    <tbody class="wsite-multicol-tbody">
			      <tr class="wsite-multicol-tr">
				<!--
				    <div class="content">				    
				    <img src="interfaces/perrin/images/default.jpg" alt="" />
				    </div>
				-->
				<xsl:call-template name="collectionAndGroupLinks"/>
			      </tr>
			    </tbody>
			  </table>
			</div></div></div>
		      </div>
		    </div>
		  </div>
		  
		</div>
	      </div>
	      
	    </div>
	    
	  </div><!-- end main-wrap -->
		<br class="clear" />
		<div id="hpage_cats">

		  <!--<xsl:call-template name="collectionsList"/>-->
		</div>		
	</xsl:template>


	<xsl:template name="additionalHeaderContent">
		<script type="text/javascript" src="interfaces/{$interface_name}/scripts/jquery.easing.1.3.js"><xsl:text> </xsl:text></script>
		<script type="text/javascript" src="interfaces/{$interface_name}/scripts/jquery.timers.1.2.js"><xsl:text> </xsl:text></script>
		<script type="text/javascript" src="interfaces/{$interface_name}/scripts/jquery.galleryview.2.1.1.min.js"><xsl:text> </xsl:text></script>
		<script type="text/javascript" src="interfaces/{$interface_name}/scripts/jquery.galleryview.setup.js"><xsl:text> </xsl:text></script>
	</xsl:template>
	
	<xsl:template name="collectionsList">
		<!-- for every collection in the library -->
		<xsl:for-each select="./collectionList/collection">		
			<xsl:call-template name="collDescription"/>				
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="collDescription">
	  <xsl:variable name="collectionFolder" select="@name"/>
	  <xsl:variable name="collectionName" select="displayItemList/displayItem[@name='name']"/>
	  <xsl:variable name="aboutImage" select="displayItemList/displayItem[@name='icon']"/>
	  <xsl:variable name="homeImage" select="displayItemList/displayItem[@name='smallicon']"/>
	  <xsl:variable name="collDesc" select="displayItemList/displayItem[@name='description']"/>
	  <xsl:variable name="numDocs" select="metadataList/metadata[@name='numDocs']"/>
	  <!-- creates a header that links to the collection's about page -->
	  
	  <!-- if there is an About page image for the collection, this is displayed -->
	  <xsl:if test="$homeImage">
	    <div><div class="wsite-image wsite-image-border-thin " style="padding-top:10px;padding-bottom:10px;margin-left:0;margin-right:0;text-align:center">
	      <img src="sites/{$site_name}/collect/{$collectionFolder}/images/{$homeImage}" alt="{$collectionName}" title="{$collectionName}" style="max-width:100%" />
	    </div></div>
	    <div style="display:block;font-size:90%"></div>
	  </xsl:if>

	  <!-- don't centre collection description (div class=paragraph)
	       with style="text-align:center;
	       since the collection description may be HTML in its own right -->
	  <div class="paragraph">
	    <a href="{$library_name}/collection/{$collectionFolder}/page/about" title="{$collectionName}" alt="{$collectionName}"><xsl:value-of select="$collectionName"/></a>
	    <br />
	    <xsl:choose>
	      <!-- has a description - display it -->
	      <xsl:when test="$collDesc">
		
		<!--<xsl:value-of select="$collDesc" disable-output-escaping="yes"/>--><xsl:apply-templates select="displayItemList/displayItem[@name='description']"/>
	      </xsl:when>
	      <!-- no description - a generic sentence -->
	      <xsl:otherwise>
		<p class="justify">Welcome to the <xsl:value-of select="$collectionName"/> collection. This collection contains <xsl:value-of select="$numDocs"/> documents.</p>
	      </xsl:otherwise>
	    </xsl:choose>
	  </div>
	</xsl:template>
	
	<xsl:template name="collectionAndGroupLinks">
	  <xsl:for-each select="collectionList/collection|groupList/group">
            <xsl:sort data-type="number" select="@position"/>
	    <td class="wsite-multicol-col" style="width:33.333333333333%; padding:0 15px;">
	      <xsl:if test="name() = 'collection'">
	      <xsl:call-template name="collDescription"/>
	    </xsl:if>
	    <xsl:if test="name() = 'group'">
	      <xsl:call-template name="customGroupDescription"/>
	    </xsl:if>
	    </td>
          </xsl:for-each>
	  
	</xsl:template>
	<xsl:template match="/page/xsltparams">
	  <!-- suppress xsltparam block in page -->
	</xsl:template>

	<!-- Modified version of <gslib:groupLinkWithImage/>-->
	<xsl:template name="customGroupDescription">
	  <xsl:variable name="short"><xsl:value-of select="shortDescription"/></xsl:variable>
	  <xsl:variable name="desc"><xsl:value-of select="description"/></xsl:variable>
	  <xsl:variable name="group_href"><xsl:value-of select="$library_name"/>/group/<xsl:if test="/page/pageRequest/paramList/param[@name='group']"><xsl:value-of select="/page/pageRequest/paramList/param[@name='group']/@value"/>/</xsl:if><xsl:value-of select="@name"/></xsl:variable>
	  
	  
	  <!-- if there is an image for this group, this is displayed -->	  
	  <xsl:if test="util:checkFileExistence($site_name, backgroundImage)">
	    <div><div class="wsite-image wsite-image-border-thin " style="padding-top:10px;padding-bottom:10px;margin-left:0;margin-right:0;text-align:center">
	      <img class="groupLinkImage">
		<xsl:attribute name="alt"><xsl:value-of select="@name"/></xsl:attribute>
		<xsl:attribute name="title"><xsl:value-of select="@name"/></xsl:attribute>
		<xsl:attribute name="style"><xsl:text>max-width:100%</xsl:text></xsl:attribute>
		<xsl:attribute name="src">sites/<xsl:value-of select="$site_name"/>/<xsl:value-of select="backgroundImage"/></xsl:attribute>
	      </img>
	    </div></div>
	    <div style="display:block;font-size:90%"></div>
	  </xsl:if>

	  <!-- some text for the group -->
	  <div class="paragraph" style="text-align:center;">
	    <!-- group title links to the collection's about page -->
	    <a href="{$group_href}" title="{$short}" alt="{$short}">
	      <xsl:choose>
		<xsl:when test="boolean(title)">
		  <xsl:value-of select="title"/>
		</xsl:when>
		<xsl:otherwise>
		  <xsl:value-of select="@name"/>
		</xsl:otherwise>
	      </xsl:choose>
	    </a>
	    <br />	    
	    <xsl:choose>
	      <!-- If the group has a description - display it -->
	      <xsl:when test="$desc">
		<xsl:value-of select="$desc" disable-output-escaping="yes"/>
	      </xsl:when>
	      <!-- If no group description - repeat group name -->
	      <xsl:otherwise>
		Collection group: <xsl:value-of select="@name" disable-output-escaping="yes"/>
	      </xsl:otherwise>
	    </xsl:choose>
	  </div>
	  
	</xsl:template>

</xsl:stylesheet>


